<h3 align="center">JuracusApi Typescript SDK</h3>

  <p align="center">
    Typescript SDK to analyze legal documents with the Juracus API
    </p>



<!-- TABLE OF CONTENTS -->
<details open="open">
  <summary>Table of Contents</summary>
  <ol>
    <li>
      <a href="#about-the-project">About the Project</a>
      <ul>
        <li><a href="#built-with">Built With</a></li>
      </ul>
    </li>
    <li>
      <a href="#getting-started">Getting Started</a>
      <ul>
        <li><a href="#installation">Installation</a></li>
        <li><a href="#usage">Usage</a></li>
      </ul>
    </li>
    <li><a href="#troubleshooting">Troubleshooting</a></li>
    <li><a href="#license">License</a></li>
    <li><a href="#contact">Contact</a></li>
  </ol>
</details>



<!-- ABOUT THE PROJECT -->

## About the Project

The Juracus API provides access to Legal Analytic’s Artificial Intelligence “Juracus”. It can be used to extractvarious contents from legal documents without worrying about deep learning natural language processing models.

### Built with

| Library | License(s) |
|---------|-----|
| [WS](https://github.com/websockets/ws) | [MIT License](https://github.com/websockets/ws/blob/master/LICENSE) |
| [Axios](https://github.com/axios/axios) | [MIT License](https://github.com/axios/axios/blob/master/LICENSE) |
| [Typescript-Starter](https://github.com/bitjson/typescript-starter) | [MIT License](https://github.com/bitjson/typescript-starter/blob/master/LICENSE) |

<!-- GETTING STARTED -->

## Getting Started

To install the SDK add it to your project dependencies like so

### NPM

```sh
npm install legal-analytics-sdk
```

### YARN

```sh
yarn add legal-analytics-sdk
```

<!-- USAGE EXAMPLES -->

### Usage

To use the ```JuracusClient``` you can access the instance with your custom API-Key

```typescript
const client = JuracusClient.getInstance("your-api-key");
```

Afterwards, the client connects to the API and you can start the analysis:

```typescript
// file format to process
const fileFormat = DataFormat.PDF; // DOC, DOCX, HTML, PDF, RAW

const data = "encodedBase64String" // Blob or Buffer possible

// choose the legal properties to analyze
const criteriaList = [Criterion.DATA_DELETION_AND_RETURN];

// pass a request to the API
const response = client.analyzeAsyncFromCriteria(fileFormat, data, criteriaList);
```

| Parameter             | Description                                              |
| --------------------- | -------------------------------------------------------- |
| fileFormat            | format of the file to analyze (e.g. PDF or DOCX)         |
| data | contains the data of the file to analyze in this case Base64 encoded  |
| criteriaList          | collection of legal properties (criteria) to find        |

Instead of passing base64 encoded strings you can always pass a ```Buffer``` or ```Blob``` object as an alternative.
When calling ```analyzeAsyncFromCriteria``` a ```Promise``` object is returned containing the ```ApiResponse```. You can access the text paragraphs our AI detected using the ```getClauses(Criterion)``` method:

```typescript

import { Clause } from './Clause';

// Get the ApiResponse from the Promise.
const result = await response;

// List of all text paragraphs which deal with 'data deletion' or 'returning of data'.
const clauses = result.getClauses(Criterion.DATA_DELETION_AND_RETURN);

// Iterate over all found text paragraphs (clauses)
clauses.forEach((clause: Clause) => {
  // Print the found paragraphs
  console.log(clause.clauseText);
})

  
```

Additionally, you can define ```ApiOptions``` in your analysis request which will change the returned results. For example, enabling the option ```ApiOption.CONFIDENCE``` will provide a floating point value between 0.0 and 1.0 for each ```Clause```. The value indicates how certain the AI is, that its prediction is correct. The larger the value, the higher the AI's confidence. You can enableApiOptions as follows:

```typescript

import { ApiOptions } from './ApiOptions';
import { ApiResponse } from './ApiResponse';
import { Clause } from './Clause';

// ... code as in the previous example

// Enable the ApiOption 'CONFIDENCE' as described above
const defaultOptions = new ApiOptions();
defaultOptions.enable(ApiOption.CONFIDENCE);

// Send the request
const response = client.analyzeAsyncFromCriteriaWithOptions(fileFormat, data, criteriaList, defaultOptions);

// ... code as in the previous example

// Iterate over all found clauses and print them together with the confidence value
clauses.forEach((clause: Clause) => {
  console.log(`Confidence :  ${clause.confidence} `);
  console.log(`Clause Text:  ${clause.clauseText} `);
})
```

You can add options for all criteria at once as shown above or pass an ```ApiOptions``` object for each ```Criterion``` by creating a ```Map<Criterion, ApiOptions>```. ome options are enabled by default, which you can check using ```ApiOption.[?].isEnabledByDefault```.
There are multiple ways to analyze a file:

- ```typescript 
  const analyzeAsyncFromCriteria = async (dataFormat: DataFormat, data: string | Blob | Buffer, criteria: readonly Criterion[]) => Promise<ApiResponse> 
  ```

- ```typescript 
  const analyzeAsyncFullSpecification = async (dataFormat: DataFormat, data: string | Blob | Buffer, tasks: Map<Criterion, ApiOptions>) => Promise<ApiResponse>
  ```

- ```typescript 
  const analyzeAsyncFromCriteriaWithOptions = async (dataFormat: DataFormat, data: string | Blob | Buffer, criteria: readonly Criterion[], defaultOptions: ApiOptions) => Promise<ApiResponse>
  ```
  
## Troubleshooting

As the API and SDK are currently in development, there is always the chance that something goes wrong. Therefore, each ```ApiResponse``` contains a ```List``` of ```ApiError``` objects. You can access all errors using the ```errors``` property on your ```ApiResponse```:

```typescript
// did any errors occur?
if(response.hasErrors()) {
  // print all errors
  response.errors.forEach((error: ApiError) => {
    console.log(error.description)
  })
}
```

| Name | Type | Description |
|------|------| -------------|
|  ID  | ```string``` | Unique identifier for the error |
|  Name  | ```string``` | Short name or description |
|  Description  | ```string``` | Detailed description |
|  Error Code  | ```int``` | Code for this type of error |
|  Source  | ```ApiStage``` | Where the error occurred |
<!-- LICENSE -->

## License

Distributed under the MIT License. See `LICENSE` for more information.

<!-- CONTACT -->

## Contact

Having trouble or suggestions?

| Name | LinkedIn | E-Mail | Field |
|------|----------|--------|----------|
| Onur Gürsoy | https://www.linkedin.com/in/onur-g%C3%BCrsoy-it/ | guersoy@juracus.de | Backend |
| Till Werner | https://www.linkedin.com/in/till-w-0a0a24200/ | werner@juracus.de | Artificial Intelligence |
| David Schonebeck | https://www.linkedin.com/in/david-schonebeck/ | schonebeck@juracus.de | Sales & Pricing |
