import { ApiMetadata } from './ApiMetadata';
import { ApiMetadataKey } from './ApiMetadataKey';
import { SparseClause } from './SparseClause';
/**
 * Juracus Analysis results for a specific criterion.
 *
 * @author Onur Gürsoy
 */
export declare class AnalysisResults {
    readonly metadata: ReadonlyMap<ApiMetadataKey, ApiMetadata<any>>;
    readonly pId: string;
    readonly clauses: SparseClause[];
    readonly foundFlag: boolean;
    readonly id: string;
    /**
     * Constructs a new {@link AnalysisResults} object containing the analysis results for the specified criterion.
     *
     * @param pId - UUID of the {@link Criterion} the result belongs to.
     * @param clauses     - {@link Array} of analyzed texts. Defaults to an empty {@link Array} if {@code null}.
     * @param foundFlag   - {@link Boolean} specifying whether or not at least one as relevant classified clause was found.
     * @param metadata    - {@link Map} for additional metadata. Defaults to an empty {@link Map} if {@code null}.
     */
    constructor(metadata: ReadonlyMap<ApiMetadataKey, ApiMetadata<any>>, pId: string, clauses?: SparseClause[], foundFlag?: boolean);
    /**
     * Returns the {@link ApiMetadataKey}s for which contents are available.
     *
     * @return {@link Set} of {@link ApiMetadataKey}s for which contents are available.
     */
    readonly availableMetadataKeys: () => Set<ApiMetadataKey>;
}
